@@ -181,8 +181,10 @@ selection_table <- function(X, max.dur = 10, path = NULL, whole.recs = FALSE,
   { 
     exp.size <- sum(round(check.results$bits * check.results$sample.rate * (check.results$duration + (mar * 2)) / 4) / 1024 )
     
-    if (confirm.extended)
-      answer <- readline(prompt = paste0("Expected 'extended_selection_table' size is ~", ifelse(round(exp.size) == 0, round(exp.size, 2), round(exp.size)), "MB (~", round(exp.size/1024, 5), " GB) \n Do you want to proceed (y/n): \n")) else answer <- "yeah dude!"
+    if (confirm.extended){
+      cat(crayon::magenta(paste0("Expected 'extended_selection_table' size is ~", ifelse(round(exp.size) == 0, round(exp.size, 2), round(exp.size)), "MB (~", round(exp.size/1024, 5), " GB) \n Do you want to proceed? (y/n): \n")))
+      answer <- readline(prompt = "")
+      } else answer <- "yeah dude!"
       
       if (substr(answer, 1, 1) %in% c("y", "Y")) # if yes
       {
@@ -287,7 +289,7 @@ selection_table <- function(X, max.dur = 10, path = NULL, whole.recs = FALSE,
   
   attributes(X)$warbleR.version <- packageVersion("warbleR")
   
-  if (extended & confirm.extended & !is_extended_selection_table(X)) cat("'extended_selection_table' was not created")
+  if (extended & confirm.extended & !is_extended_selection_table(X)) cat(crayon::silver(crayon::bold("'extended_selection_table' was not created")))
   
   return(X)
 }
@@ -486,35 +488,55 @@ is_extended_selection_table <- function(x) inherits(x, "extended_selection_table
 
 print.extended_selection_table <- function(x, ...) {
   
-  cat(paste("object of class 'extended_selection_table' \n contains a selection table data frame with"), nrow(x), "rows and", ncol(x), "columns: \n")
+  # to exclude printing of column names below the table
+  options(huxtable.print = function (h) {
+    huxtable::print_screen(h, colnames = FALSE, color = TRUE)
+    cat("\n")
+  })
   
-  print(head(as.data.frame(x)))
+  cat(crayon::cyan(paste("Object of class", crayon::bold("'extended_selection_table' \n"))))
   
-  if (nrow(x) > 6) cat(paste0("... and ", nrow(x) - 6, " more rows \n"))  
+  cat(crayon::silver(paste(crayon::bold("Contains:"), "\n* A selection table data frame with"), nrow(x), "rows and", ncol(x), "columns: \n"))
   
-  cat(paste0(length(attr(x, "wave.objects"))," wave objects (as attributes): \n"))
+  #print data frame as table
+  tb <- try(huxtable::set_text_color(huxtable::theme_basic(huxtable::as_hux(head(as.data.frame(x)))), "silver"), silent = TRUE)
   
-  print(head(names(attr(x, "wave.objects"))))
+  if(is(tb, "try-error")) tb <- head(as.data.frame(x))
   
-  if (length(attr(x, "wave.objects")) > 6) cat(paste0("... and ", length(attr(x, "wave.objects")) - 6, " more \n"))  
+  print(tb)
   
-  cat("and a data frame (check.results) generated by check_sels() (as attribute) \n")
+  if (nrow(x) > 6) cat(crayon::silver(paste0("... and ", nrow(x) - 6, " more rows \n")))  
   
-  if (attr(x, "by.song")[[1]]) cat("the selection table was created by song (see 'class_extended_selection_table') \n") else
-    cat("the selection table was created by element (see 'class_extended_selection_table') \n")
+  cat(crayon::silver(paste0("\n* ", length(attr(x, "wave.objects"))," wave objects (as attributes): ")))
+  
+  
+  cat(crayon::silver(head(names(attr(x, "wave.objects")))))
+  
+  if (length(attr(x, "wave.objects")) > 6) cat(crayon::silver(paste0("... and ", length(attr(x, "wave.objects")) - 6, " more")))  
+
+    cat("\n ")
+  
+  cat(crayon::silver("\n* A data frame (check.results) generated by check_sels() (as attribute) \n"))
+  
+  if (attr(x, "by.song")[[1]]) cat(crayon::silver(paste0( crayon::bold("\nAdditional information:"), "\n* The selection table was created", crayon::italic(crayon::bold(" by song ")), "(see 'class_extended_selection_table') \n"))) else
+    cat(crayon::silver(paste0("\nThe selection table was created", crayon::italic(crayon::bold(" by element ")), "(see 'class_extended_selection_table') \n")))
 
   # print number of sampling rates
   smp.rts <- unique(attr(x, "check.results")$sample.rate)
-  cat(paste0(length(smp.rts), " sampling rate(s): ", paste(smp.rts, collapse = "/"), " \n"))
+  if (length(smp.rts) == 1)
+  cat(crayon::silver(paste0("* ", length(smp.rts), " sampling rate(s) (in kHz): ", paste(crayon::bold(smp.rts), collapse = "/"), " \n"))) else
+    cat(crayon::red(paste0("* ", length(smp.rts), " sampling rate(s): ", paste(crayon::bold(smp.rts), collapse = "/"), " \n")))
 
   # print number of sampling rates
   bt.dps <- unique(attr(x, "check.results")$bits)
-  cat(paste0(length(bt.dps), " bit depth(s): ", paste(bt.dps, collapse = "/"), " \n"))
+  if (length(bt.dps) == 1)
+  cat(crayon::silver(paste0("* ", length(bt.dps), " bit depth(s): ", paste(crayon::bold(bt.dps), collapse = "/"), " \n"))) else
+    cat(crayon::red(paste0("* ", length(bt.dps), " bit depth(s): ", paste(crayon::bold(bt.dps), collapse = "/"), " \n")))
   
   # print warbleR version
   if (!is.null(attr(x, "warbleR.version")))
-    cat(paste0("created by warbleR ", attr(x, "warbleR.version"))) else
-      cat("created by warbleR < 1.1.21")
+    cat(crayon::silver(paste0("* Created by warbleR ", attr(x, "warbleR.version")))) else
+      cat(crayon::silver("* Created by warbleR < 1.1.21"))
   }
 
 ##############################################################################################################
@@ -530,18 +552,31 @@ print.extended_selection_table <- function(x, ...) {
 
 print.selection_table <- function(x, ...) {
   
-  cat(paste("object of class 'selection_table' \n contains a selection table data frame with"), nrow(x), "rows and", ncol(x), "columns: \n")
+  # to exclude printing of column names below the table
+  options(huxtable.print = function (h) {
+    huxtable::print_screen(h, colnames = FALSE, color = TRUE, compact = FALSE, ceiling(getOption("width")/3))
+    cat("\n")
+  })
   
-  print(head(as.data.frame(x)))
+  cat(crayon::cyan(paste("Object of class", crayon::bold("'selection_table' \n"))))
   
-  if (nrow(x) > 6) cat(paste0("... and ", nrow(x) - 6, " more rows \n"))  
+  cat(crayon::silver(paste(crayon::bold("Contains:"), "\n*  A selection table data frame with"), nrow(x), "rows and", ncol(x), "columns: \n"))
   
-  cat("and a data frame (check.results) generated by check_sels() (as attribute) \n")
+  #print data frame as table
+  tb <- try(huxtable::set_text_color(huxtable::theme_basic(huxtable::as_hux(head(as.data.frame(x)))), "silver"), silent = TRUE)
+  
+  if(is(tb, "try-error")) tb <- head(as.data.frame(x))
+  
+  print(tb)
+  
+  if (nrow(x) > 6) cat(crayon::silver(paste0("... and ", nrow(x) - 6, " more rows \n")))  
+  
+  cat(crayon::silver("\n * A data frame (check.results) generated by check_sels() (as attribute) \n"))
   
   # print warbleR version
   if (!is.null(attr(x, "warbleR.version")))
-   cat(paste0("created by warbleR ", attr(x, "warbleR.version"))) else
-     cat("created by warbleR < 1.1.21")
+    cat(crayon::silver(paste0("created by warbleR ", attr(x, "warbleR.version")))) else
+      cat(crayon::silver("created by warbleR < 1.1.21"))
 }
 
 ##############################################################################################################
